@@ -2,9 +2,9 @@
  * File:                context_menu.c
  * Created:             April 2008
  * Created by:          Axel von Bertoldi
- * Last Modified:       April 2009
+ * Last Modified:       November 2009
  * Last Modified by:    Axel von Bertoldi
- * (C) 2005-2008        Axel von Bertoldi
+ * (C) 2005-2009        Axel von Bertoldi
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -170,8 +170,8 @@ context_menu_add_new_dir_callback (GtkWidget *menu_item, gchar *file_name) {
 
     GtkBuilder* builder = gtk_builder_new();
     /*gtk_builder_add_from_file (builder, BUILDER_UI_PATH, &error);*/
-    gchar *toplevel = "new_dir_dialog";
-    gtk_builder_add_objects_from_file (builder, BUILDER_UI_PATH, &toplevel, &error);
+    gchar *toplevel[] = {"new_dir_dialog", NULL};
+    gtk_builder_add_objects_from_file (builder, BUILDER_UI_PATH, toplevel, &error);
     if (!utils_gerror_ok(&error, TRUE)) {
         return;
     }
@@ -365,7 +365,107 @@ context_menu_add_trash_item (const gchar *file_name, GtkWidget *menu) {
 }
 /******************************************************************************/
 static void
-context_menu_populate (const gchar *file_name, GtkWidget *menu) {
+context_menu_add_open_terminal (const gchar *file_name,
+                                GtkWidget *menu,
+                                ContextMenuPrefs prefs) {
+    if (!vfs_file_is_directory (file_name)) return;
+    {
+        GtkWidget *menu_item = gtk_image_menu_item_new_with_mnemonic (_("Open _Terminal Here"));
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
+                                       gtk_image_new_from_icon_name ("gnome-terminal",
+                                                                     GTK_ICON_SIZE_MENU));
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+        context_menu_setup_callback (prefs.terminal, file_name,
+                                     GTK_MENU_ITEM (menu_item),
+                                     GTK_MENU (menu));
+    }
+    {
+        GtkWidget *menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Open As Root"));
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
+                                       gtk_image_new_from_icon_name ("file-manager",
+                                                                     GTK_ICON_SIZE_MENU));
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+        gchar *exec = vfs_get_default_mime_application (file_name);
+        gchar *cmd = g_strdup_printf ("gksu %s", exec);
+        context_menu_setup_callback (cmd, file_name,
+                                     GTK_MENU_ITEM (menu_item),
+                                     GTK_MENU (menu));
+        g_free (cmd);
+        g_free (exec);
+    }
+    {
+        GtkWidget *menu_item = gtk_image_menu_item_new_with_mnemonic (_("Open Terminal As _Root"));
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
+                                       gtk_image_new_from_icon_name ("gksu-root-terminal",
+                                                                     GTK_ICON_SIZE_MENU));
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+        gchar *cmd = g_strdup_printf ("gksu %s", prefs.terminal);
+        context_menu_setup_callback (cmd, file_name,
+                                     GTK_MENU_ITEM (menu_item),
+                                     GTK_MENU (menu));
+        g_free (cmd);
+    }
+}
+/******************************************************************************/
+static void
+context_menu_add_edit_file (const gchar *file_name,
+                            GtkWidget *menu,
+                            ContextMenuPrefs prefs) {
+    if (vfs_file_is_directory (file_name)) return;
+
+    GtkWidget *menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Edit File"));
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
+                                   gtk_image_new_from_stock (GTK_STOCK_EDIT,
+                                                             GTK_ICON_SIZE_MENU));
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+    context_menu_setup_callback (prefs.editor,
+                                 file_name,
+                                 GTK_MENU_ITEM (menu_item),
+                                 GTK_MENU (menu));
+
+
+    menu_item = gtk_image_menu_item_new_with_mnemonic (_("Edit File As _Root"));
+    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
+                                   gtk_image_new_from_icon_name (GTK_STOCK_EDIT,
+                                                                 GTK_ICON_SIZE_MENU));
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+    gchar *cmd = g_strdup_printf ("gksu %s", prefs.editor);
+
+    context_menu_setup_callback (cmd,
+                                 file_name,
+                                 GTK_MENU_ITEM (menu_item),
+                                 GTK_MENU (menu));
+    g_free (cmd);
+
+
+    if (vfs_file_is_executable (file_name)) {
+        menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Run As Root"));
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item),
+                                       gtk_image_new_from_icon_name ("gksu-root-terminal",
+                                                                     GTK_ICON_SIZE_MENU));
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+
+        gchar *cmd = g_strdup_printf ("gksu %s", file_name);
+
+        context_menu_setup_callback (cmd,
+                                     NULL,
+                                     GTK_MENU_ITEM (menu_item),
+                                     GTK_MENU (menu));
+        g_free (cmd);
+    }
+
+}
+/******************************************************************************/
+static void
+context_menu_populate (const gchar *file_name,
+                       GtkWidget *menu,
+                       ContextMenuPrefs prefs) {
+
+    context_menu_add_open_terminal (file_name, menu, prefs);
+    context_menu_add_edit_file (file_name, menu, prefs);
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
     context_menu_add_open_with_item (file_name, menu);
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), gtk_separator_menu_item_new());
     context_menu_add_new_dir (file_name, menu);
@@ -379,7 +479,9 @@ context_menu_populate (const gchar *file_name, GtkWidget *menu) {
 }
 /******************************************************************************/
 gboolean
-context_menu_display (const gchar *file_name, GtkWidget *parent_menu_item) {
+context_menu_display (const gchar *file_name,
+                      GtkWidget *parent_menu_item,
+                      ContextMenuPrefs prefs) {
     int event_button;
     int event_time;
 
@@ -410,7 +512,7 @@ context_menu_display (const gchar *file_name, GtkWidget *parent_menu_item) {
                       G_CALLBACK (restore_grabs),
                       parent_menu_item);
 
-    context_menu_populate (file_name, menu);
+    context_menu_populate (file_name, menu, prefs);
 
     /* disable the menu browser to get around the focus bug */
     tree_set_sensitive (parent_menu_item, FALSE);
