@@ -2,9 +2,9 @@
  * File:                main.c
  * Created:             September 2005
  * Created by:          Axel von Bertoldi
- * Last Modified:       April 2009
+ * Last Modified:       November 2009
  * Last Modified by:    Axel von Bertoldi
- * (C) 2005-2008        Axel von Bertoldi
+ * (C) 2005-2009        Axel von Bertoldi
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -31,7 +31,6 @@
 
 #define APPLET_IID          "OAFIID:GNOME_FileBrowserApplet"
 #define APPLET_FACTORY_IID  "OAFIID:GNOME_FileBrowserApplet_Factory"
-#define VERSION             "0.6.4"
 
 /******************************************************************************/
 static const gchar file_browser_applet_menu_xml [] =
@@ -83,6 +82,7 @@ file_browser_applet_display_about_dialog (GtkWidget *widget) {
         "Serkan Kaba <serkan@gentoo.org>",
         "Silvio Ricardo Cordeiro <silvioricardoc@gmail.com>",
         "pachoramos",
+        "Ivan Baldo <ibaldo@adinet.com.uy>",
         NULL
     };
     const gchar *documenters [] = {
