@@ -2,9 +2,9 @@
  * File:                vfs.c
  * Created:             August 2008
  * Created by:          Axel von Bertoldi
- * Last Modified:       March 2008
+ * Last Modified:       November 2009
  * Last Modified by:    Axel von Bertoldi
- * (C) 2005-2008        Axel von Bertoldi
+ * (C) 2005-2009        Axel von Bertoldi
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -32,6 +32,23 @@
 #include "utils.h"
 #include "config.h"
 
+/******************************************************************************/
+const gchar *size_units[] = {"bytes","KB","MB","GB","TB","HUGE",NULL};
+/******************************************************************************/
+/* Caller must free return value. */
+static inline gchar * vfs_human_file_size (guint64 size) {
+    int order_of_magnitude = 0;
+    double _size = size;
+    while (_size > 1024){
+        _size = _size / 1024;
+        order_of_magnitude++;
+    }
+    gchar *human_size = g_strdup_printf ("%.1f %s", _size,
+                                         (order_of_magnitude <= 5 ?
+                                          size_units[order_of_magnitude] :
+                                          size_units[5]));
+    return human_size;
+}
 /******************************************************************************/
 /* sort the structures based on the file's display_name */
 static inline gint
@@ -276,9 +293,10 @@ vfs_get_dir_listings (GPtrArray *files,
                       GPtrArray *dirs,
                       gboolean show_hidden,
                       gboolean show_thumbnail,
+                      gboolean hide_files,
                       const gchar *path) {
     GError *error = NULL;
-    const gchar *_attributes = "standard::type,standard::is-hidden,standard::name,standard::display-name,access::can-execute";
+    const gchar *_attributes = "standard::type,standard::is-hidden,standard::name,standard::display-name,access::can-execute,standard::size";
     gchar *attributes = show_thumbnail ? g_strdup_printf ("%s,thumbnail::path", _attributes) : g_strdup(_attributes);
 
     GFile *file = g_file_new_for_path (path);
@@ -303,6 +321,11 @@ vfs_get_dir_listings (GPtrArray *files,
             g_object_unref (file_info);
             continue;
         }
+        if (g_file_info_get_file_type (file_info) != G_FILE_TYPE_DIRECTORY && hide_files) {
+            g_object_unref (file_info);
+            continue;
+        }
+
         VfsFileInfo *vfs_file_info = g_new0 (VfsFileInfo ,1);
         vfs_file_info->icon = NULL;
 
@@ -329,6 +352,8 @@ vfs_get_dir_listings (GPtrArray *files,
             vfs_file_info->icon = vfs_get_icon_for_file (vfs_file_info->file_name); 
         }
 
+        vfs_file_info->size = vfs_human_file_size (g_file_info_get_size (file_info));
+
         /* add it to the array */
         if (g_file_info_get_file_type (file_info) == G_FILE_TYPE_DIRECTORY) {
             g_ptr_array_add (dirs, (gpointer)vfs_file_info);
